@@ -32,3 +32,24 @@ class NameConflictError(Exception):
 
     def __init__(self, plugin: str, name: str) -> None:
         super().__init__(f"plugin name conflict at {plugin}: '{name}'")
+
+
+class NotARepositoryError(OSError):
+    """Raise if there is an error related to a Git repository."""
+
+    def __init__(self) -> None:
+        super().__init__("not a git repository")
+
+
+class PythonPackageNotFoundError(OSError):
+    """Raise if Python package not found in project."""
+
+    def __init__(self) -> None:
+        super().__init__("no packages found")
+
+
+class CommandNotFoundError(OSError):
+    """Raise when subprocess called is not on system."""
+
+    def __init__(self, cmd: str) -> None:
+        super().__init__(f"{cmd}: command not found...")
